%define scim_api 1.4.0

Name:      scim
Version:   1.4.4
# must be less than the release number of scim in Core
Release:   1%{?dist}
Summary:   Smart Common Input Method platform

License:   LGPL
Group:	   System Environment/Libraries
URL:       http://www.scim-im.org/
Source0:   http://dl.sourceforge.net/sourceforge/scim/%{name}-%{version}.tar.gz
Source1:   xinput-scim
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

PreReq:    %{_bindir}/update-gtk-immodules
BuildRequires: gtk2-devel, desktop-file-utils
# for autoreconf
Buildrequires: gettext-devel
Patch1:    scim-add-restart.patch
Patch2:    gtkimm-clear-preedit-on-reset-174143.patch
Patch3:    rawcode-unicode-maxlength.patch
Patch4:    scim.pc-versioned-moduledir-179706.patch
Patch5:    scim-panjabi-punjabi.patch

%description
SCIM is a user friendly and full featured input method user interface and
also a development platform to make life easier for Input Method developers.


%package devel
Summary:    Smart Common Input Method platform
Group:      Development/Libraries
Requires:   %{name}-libs = %{version}-%{release}
Requires:   gtk2-devel

%description devel
The scim-devel package includes the header files for the scim package.
Install scim-devel if you want to develop programs which will use scim.


%package doc
Summary:    Smart Common Input Method platform documentation
Group:      Documentation

%description doc
SCIM development documentation files generated from the sourcecode.


%package libs
Summary:    Smart Common Input Method libraries
Group:      System Environment/Libraries

%description libs
This package provides the libraries and GTK input method module for SCIM.


%prep
%setup -q
%patch1 -p1 -b .1-restart
%patch2 -p1 -b .2-reset
%patch3 -p0 -b .3-unicode
%patch4 -p1 -b .4-moduledir
%patch5 -p0 -b .5-panjabi
# patch1 touches configure.ac and src/Makefile.am
autoreconf


%build
# symbol versioning enabled for FC3 and RHEL4
%configure --disable-static --enable-ld-version-script
make %{?_smp_mflags}


%install
rm -rf ${RPM_BUILD_ROOT}
make DESTDIR=${RPM_BUILD_ROOT} install

mkdir -pm 755 ${RPM_BUILD_ROOT}/%{_libdir}/scim-1.0/{Config,FrontEnd,IMEngine,SetupUI,Helper}

# remove .la files
find ${RPM_BUILD_ROOT} -name '*.la' | xargs rm

# install setup panel
desktop-file-install \
  --delete-original                                     \
  --vendor fedora                                       \
  --dir ${RPM_BUILD_ROOT}/%{_datadir}/applications      \
  --add-category X-Fedora                               \
  ${RPM_BUILD_ROOT}/%{_datadir}/applications/scim-setup.desktop

# remove capplet
rm ${RPM_BUILD_ROOT}/%{_datadir}/control-center-2.0/capplets/scim-setup.desktop

# install xinput config file.
mkdir -pm 755 ${RPM_BUILD_ROOT}/%{_sysconfdir}/X11/xinit/xinput.d
install -pm 644 %{SOURCE1} ${RPM_BUILD_ROOT}/%{_sysconfdir}/X11/xinit/xinput.d/scim

%find_lang %{name}


%clean
rm -rf ${RPM_BUILD_ROOT}

%define cjk_langs ja_JP ko_KR zh_CN zh_TW
%define indic_langs bn_IN gu_IN hi_IN kn_IN ml_IN pa_IN ta_IN te_IN
%define supported_langs %{cjk_langs} %{indic_langs} ne_NE th_TH


%post
for llcc in %{supported_langs}; do
   %{_sbindir}/alternatives --install %{_sysconfdir}/X11/xinit/xinput.d/$llcc xinput-$llcc %{_sysconfdir}/X11/xinit/xinput.d/scim 81
done


%post libs
/sbin/ldconfig
%{_bindir}/update-gtk-immodules %{_target_platform}


%postun
if [ "$1" = "0" ]; then
   for llcc in %{supported_langs}; do
      %{_sbindir}/alternatives --remove xinput-$llcc %{_sysconfdir}/X11/xinit/xinput.d/scim || :
      # if alternative was set to manual scim, reset to auto
      [ -L %{_sysconfdir}/alternatives/xinput-$llcc -a "`readlink %{_sysconfdir}/alternatives/xinput-$llcc`" = "%{_sysconfdir}/X11/xinit/xinput.d/scim" ] && %{_sbindir}/alternatives --auto xinput-$llcc || :
   done
fi

%postun libs
/sbin/ldconfig
%{_bindir}/update-gtk-immodules %{_target_platform}


%files -f %{name}.lang
%defattr(-,root,root,-)
%doc AUTHORS COPYING NEWS README ChangeLog TODO
%dir %{_sysconfdir}/scim
%config(noreplace) %{_sysconfdir}/scim/*
%{_sysconfdir}/X11/xinit/xinput.d
%{_bindir}/*
%{_libdir}/scim-1.0
%exclude %{_libdir}/scim-1.0/%{scim_api}
%{_datadir}/scim
%{_datadir}/pixmaps/*
%{_datadir}/applications/fedora-scim-setup.desktop

%files devel
%defattr(-,root,root,-)
%doc docs/developers
%{_includedir}/scim-1.0
%{_libdir}/libscim*.so
%{_libdir}/pkgconfig/*.pc

%files doc
%defattr(-,root,root,-)
%doc docs/html

%files libs
%defattr(-,root,root,-)
%{_libdir}/libscim-*.so.*
%{_libdir}/gtk-2.0/immodules
%{_libdir}/scim-1.0/%{scim_api}


%changelog
* Fri Feb 24 2006 Jens Petersen <petersen@redhat.com> - 1.4.4-1%{?dist}
- update to 1.4.4 release
- sync with core devel package:

* Wed Feb 22 2006 Jens Petersen <petersen@redhat.com> 
- fix Punjabi spelling with scim-panjabi-punjabi.patch (aalam)

* Thu Feb  9 2006 Jens Petersen <petersen@redhat.com>
- do not change scim_binary_version in scim.pc-versioned-moduledir-179706.patch

* Fri Feb  3 2006 Jens Petersen <petersen@redhat.com>
- add gtkimm-clear-preedit-on-reset-174143.patch to clear the preedit buffer
  when IME turned off (Qian Shen, #174143)
- add rawcode-unicode-maxlength.patch to improve input of unicode codes
  (James Su, #173102)
- add scim.pc-versioned-moduledir-179706.patch to include api version in
  moduledir in scim.pc so that IMEs get installed in versioned dir by default
  (Akira Tagoh, #179706)

* Fri Jan 13 2006 Jens Petersen <petersen@redhat.com>
- update to 1.4.4 bugfix release
  - scim-gtk-langs-167090.patch no longer needed since 1.4.3
- move scim dl modules to scim-libs for multilib to work correctly
  - define %%scim_api

* Tue Nov  1 2005 Jens Petersen <petersen@redhat.com> - 1.4.2-5%{?dist}
- avoid errors in postun script when uninstalling

* Thu Oct  6 2005 Jens Petersen <petersen@redhat.com> - 1.4.2-4%{?dist}
- fixing quoting in scim-restart
- make post and postun scripts for scim-libs

* Thu Sep 22 2005 Jens Petersen <petersen@redhat.com> - 1.4.2-3%{?dist}
- make scim-devel require scim-libs
- add xinput.d entries for Indic langs

* Thu Sep 15 2005 Jens Petersen <petersen@redhat.com>
- move libs and the gtk immodule to scim-libs for multilib

* Fri Sep  9 2005 Jens Petersen <petersen@redhat.com> - 1.4.2-1%{?dist}
- improve scim-restart script to take account of the config module in use
  (Liu Cougar)

* Fri Sep  2 2005 Jens Petersen <petersen@redhat.com>
- add scim-restart script to make it easier to restart scim after updating
  IMEs with scim-add-restart.patch
- add scim-gtk-langs-167090.patch to set gtk immodule language list empty
  for now so that rhgb doesn't load scim (Warren Togami, #167088)

* Thu Aug 25 2005 Warren Togami <wtogami@redhat.com>
- configure with --enable-ld-version-script (#166041)

* Mon Aug 22 2005 Jens Petersen <petersen@redhat.com> - 1.4.2-0%{?dist}
- update to 1.4.2 release
- source scim-qtimm script if present from scim xinput script
- reduce xinput.d alternatives priority to 81

* Mon Aug  1 2005 Ryo Dairiki <ryo-dairiki@mbm.nifty.com> - 1.4.0-2.4
- quote the postun readlink test (wcalee@myrealbox.com, #164674)

* Mon Aug  1 2005 Jens Petersen <petersen@redhat.com> - 1.4.0-2.3
- bring back the xinput alternatives settings for now

* Sat Jul 30 2005 Ryo Dairiki <ryo-dairiki@mbm.nifty.com> - 1.4.0-2.2
- don't explicitly --disable-ld-version-script since this turns on versioning

* Sat Jul 30 2005 Jens Petersen <petersen@redhat.com> - 1.4.0-2.1
- own the system xinput.d dir

* Fri Jul 29 2005 Jens Petersen <petersen@redhat.com>
- sync with Core
  - remove xinput alternatives settings out to IME packages
  - drop the old Chinese manual from docs for now
  - update -devel description
  - add doc subpackage for devel documentation
  - don't set xinput.d script executable
  - no need to set XMODIFIERS explicitly in xinput.d script

* Thu Jul 28 2005 Ryo Dairiki <ryo-dairiki@mbm.nifty.com> - 1.4.0-2
- create scim-1.0 dirs to be accessible (Jens Petersen)

* Fri Jul 16 2005 Ryo Dairiki <ryo-dairiki@mbm.nifty.com> - 1.4.0-1
- update to 1.4.0 release

* Sat Jul  9 2005 Jens Petersen <petersen@redhat.com> - 1.3.3-1
- update to 1.3.3 release
- disable linking with version-scripts for now since they cause some problems
- disable building of static libs

* Tue Jul  5 2005 Jens Petersen <petersen@redhat.com> - 1.3.2-1
- update to 1.3.2 test release
- don't set xinput.d script executable
- no need to set XMODIFIERS explicitly and QT_IM_MODULE in xinput.d script

* Mon Jun 20 2005 Ryo Dairiki <ryo-dairiki@users.sourceforge.net> - 1.2.3-2
- Remove one of doubled capplets for setup.

* Sat May 28 2005 Ryo Dairiki <ryo-dairiki@users.sourceforge.net> - 1.2.3-1
- update to 1.2.3 release

* Fri Mar 13 2005 Ryo Dairiki <ryo-dairiki@users.sourceforge.net> - 1.2.2-9
- Initial packaging for Fedora Extras
- cleanup and fixes (Konstantin Ryabitsev, Jens Petersen)

* Sun Jan 9 2005 James Su <suzhe@tsinghua.org.cn>
- Remove GConf Config module.

* Wed Jan 5 2005 James Su <suzhe@tsinghua.org.cn>
- Remove table IMEngine.

* Fri Aug 6 2004 James Su <suzhe@tsinghua.org.cn>
- Move scim-launcher and scim-panel-gtk to /usr/lib/scim-1.0.

* Sun Jun 20 2004  James Su <suzhe@tsinghua.org.cn>
- Merge all things into one package.

* Sat Jun 19 2004  James Su <suzhe@tsinghua.org.cn>
- Added /usr/libexec/scim-launcher.
- Remove setup module for SocketFrontEnd and SocketIMEngine.

* Mon Mar 8 2004  James Su <suzhe@turbolinux.com.cn>
- Added scim-config-agent.

* Thu Oct 30 2003 James Su <suzhe@turbolinux.com.cn>
- Added Simplified Chinese User Manual.

* Wed Sep 03 2003 James Su <suzhe@turbolinux.com.cn>
- cleanup spec.

* Tue Sep 02 2003 James Su <suzhe@turbolinux.com.cn>
- upto 0.8.0

* Tue Jul 29 2003 James Su <suzhe@turbolinux.com.cn>
- updated to include scim-panel-gtk.

* Thu Jun 19 2003 James Su <suzhe@turbolinux.com.cn>
- updated to include scim-setup and its modules.

* Thu Apr 3 2003 James Su <suzhe@turbolinux.com.cn>
- added suite package, which includes all necessary components of SCIM.

* Tue Mar 25 2003 James Su <suzhe@turbolinux.com.cn>
- updated to v0.4.0

* Wed Feb 26 2003 James Su <suzhe@turbolinux.com.cn>
- implemented dynamic adjust feature for generic table module.
- fixed key handling bug in generic table module.

* Mon Feb 10 2003 James Su <suzhe@turbolinux.com.cn>
- Replaced highlight_start and highlight_end in scim_server
  and scim_frontend with AttributeList (scim_attributes.h)
- Moved icons/* to data/icons and gtkstringview.* to
  utils/

* Thu Jan 2 2003 James Su <suzhe@turbolinux.com.cn>
- updated configure.ac and Makefile.am
- ready to release 0.3.0

* Tue Nov 12 2002 James Su <suzhe@turbolinux.com.cn>
- merged signal system from libinti.
- implemented namespace scim.
- implemented referenced object.
- version 0.3.0

* Tue Nov 05 2002 James Su <suzhe@turbolinux.com.cn>
- minor fixes for table IM module.

* Mon Nov 04 2002 James Su <suzhe@turbolinux.com.cn>
- More IMdkit memory leak fixes.
- Table input method bugfixes.
- version 0.2.2

* Fri Nov 01 2002 James Su <suzhe@turbolinux.com.cn>
- improved table input method.
- actually fixed the memleaks within IMdkit.
- pumped the version to 0.2.1

* Thu Oct 31 2002 James Su <suzhe@turbolinux.com.cn>
- fixed some memory leaks in IMdkit
- reduced memory usage.
- upgraded to libtool-1.4.3

* Tue Oct 29 2002 James Su <suzhe@turbolinux.com.cn>
- finished Generic Table input server module.
- fixed several bugs in scim-lib.

* Thu Oct 10 2002 James Su <suzhe@turbolinux.com.cn>
- used gettext to support i18n message.
- added release info to lib name.

* Mon Sep 30 2002 James Su <suzhe@turbolinux.com.cn>
- version 0.1.4
- added Embedded Lookup Table style into X11 FrontEnd.
- use wchar_t instead of unsigned long if __STDC_ISO_10646__ defined.

* Sun Sep 22 2002 James Su <suzhe@turbolinux.com.cn>
- version 0.1.3
- config button of X11 FrontEnd was disabled.

* Fri Sep 6 2002 James Su <suzhe@turbolinux.com.cn>
- simplified the utilities and lookup table interface.

* Wed Aug 21 2002 James Su <suzhe@turbolinux.com.cn>
- version 0.1.2
- added configuration options to disable modules.
- enhanced X11 FrontEnd.

* Sun Aug 11 2002 James Su <suzhe@turbolinux.com.cn>
- version 0.1.1
- X11 FrontEnd was enhanced.

* Sat Aug 10 2002 James Su <suzhe@turbolinux.com.cn>
- version 0.1.0
- many bugfixes.
- Help window of X11 FrontEnd was implemented.
- scim can exit cleanly.

* Fri Aug 2 2002 James Su <suzhe@turbolinux.com.cn>
- SCIM 0.0.13.
- Minor bugfixes.

* Mon Jul 29 2002 James Su <suzhe@turbolinux.com.cn>
- SCIM 0.0.12.
- Minor bugfixes.

* Sun Jul 28 2002 James Su <suzhe@turbolinux.com.cn>
- SCIM 0.0.11.
- Minor bugfixes.

* Sun Jul 21 2002 James Su <suzhe@turbolinux.com.cn>
- SCIM 0.0.10.
- Added Simple Config module.

* Sat Jun 22 2002 James Su <suzhe@turbolinux.com.cn>
- first public release of SCIM.

